==> create-jest-babel-tdd-0.0.8.tgz: package/cli.js <==
#!/usr/bin/env node
const fs = require('fs');
const spawn = require('child_process').spawn;

const [, , dir, isTs] = process.argv;
if (!fs.existsSync(dir)){
  fs.mkdirSync(dir);
} else {
  return console.log('please choose another dir name')
}
const funcExp = `function sum(a, b) {
  return a + b;
}
module.exports = sum;`
const testExp = `const sum = require('./sum');

test('adds 1 + 2 to equal 3', () => {
  expect(sum(1, 2)).toBe(3);
});`
let child;
if (isTs) {
  child = spawn(`cd ${dir} && git init && yarn init -y && yarn add --dev jest babel-jest @babel/core @babel/preset-env @babel/preset-typescript && touch .gitignore && echo node_modules >> .gitignore && mkdir src`, {
    shell: true
  });
}
else {
  child = spawn(`cd ${dir} && git init && yarn init -y && yarn add --dev jest && touch .gitignore && echo node_modules >> .gitignore && mkdir src`, {
    shell: true
  });
}
child.stderr.on('data', function (data) {
  const d = fs.readFileSync('./package.json', 'utf-8');
  const objectD = JSON.parse(d);
  d.scripts = {
    "test": "jest"
  };
  fs.writeFileSync(`./${dir}/package.json`, JSON.stringify(d, null, 2));
  if (isTs) {
    const jestConfig = `
    module.exports = {
      roots: ['<rootDir>/src'],
      transform: {
        '^.+\\.tsx?$': 'ts-jest',
      },
      testRegex: '(/__tests__/.*|(\\.|/)(test|spec))\\.tsx?$',
      moduleFileExtensions: ['ts', 'tsx', 'js', 'jsx', 'json', 'node'],
    }
    `;
    const tsConfig = `
    {
      "compilerOptions": {
        "target": "es5",
        "module": "commonjs",
        "lib": ["es2015"],
        "strict": true,
        "declaration": true,
        "outDir": "dist",
        "sourceMap": true
      },
      "include": ["src/**/*"],
      "exclude": ["node_modules", "**/*.spec.ts"]
    }
    `;
    const mainFile = `
    export const sum = (a: number, b: number) => a + b;
    `;
    const mainSpecFile = `
    import { sum } from './main';

    test('should return false given external link', () => {
      expect(sum(1, 2)).toBe(3);
    })

    test('should return true given internal link', () => {
      expect(sum(1, 2)).toBe(3);
    })
    `;
    fs.writeFileSync(`./${dir}/jest.config.js`, jestConfig);
    fs.writeFileSync(`./${dir}/sum.test.js`, tsConfig);

  } else {
    fs.writeFileSync(`./${dir}/sum.js`, funcExp);
    fs.writeFileSync(`./${dir}/tsconfig.json`, testExp);
    // fs.writeFileSync(`./${dir}/src/main.ts`, mainFile);
    // fs.writeFileSync(`./${dir}/src/main.spec.ts`, mainSpecFile);
  }
});
child.stdout.on('data', function (data) {
  console.log("STDOUT:", data.toString());
});
child.on('exit', function (exitCode) {
  console.log("Child exited with code: " + exitCode);
});

==> create-jest-babel-tdd-0.0.9.tgz: package/cli.js <==
#!/usr/bin/env node
const fs = require('fs');
const spawn = require('child_process').spawn;

const [, , dir, isTs] = process.argv;
if (!fs.existsSync(dir)){
  fs.mkdirSync(dir);
} else {
  return console.log('please choose another dir name')
}
const funcExp = `function sum(a, b) {
  return a + b;
}
module.exports = sum;`
const testExp = `const sum = require('./sum');

test('adds 1 + 2 to equal 3', () => {
  expect(sum(1, 2)).toBe(3);
});`
let child;
if (isTs) {
  child = spawn(`cd ${dir} && git init && yarn init -y && yarn add --dev jest babel-jest @babel/core @babel/preset-env @babel/preset-typescript && touch .gitignore && echo node_modules >> .gitignore && mkdir src`, {
    shell: true
  });
}
else {
  child = spawn(`cd ${dir} && git init && yarn init -y && yarn add --dev jest && touch .gitignore && echo node_modules >> .gitignore && mkdir src`, {
    shell: true
  });
}
child.stderr.on('data', function (data) {
  const d = fs.readFileSync(`./${dir}/package.json`, 'utf-8');
  const objectD = JSON.parse(d);
  d.scripts = {
    "test": "jest"
  };
  fs.writeFileSync(`./${dir}/package.json`, JSON.stringify(d, null, 2));
  if (isTs) {
    const jestConfig = `
    module.exports = {
      roots: ['<rootDir>/src'],
      transform: {
        '^.+\\.tsx?$': 'ts-jest',
      },
      testRegex: '(/__tests__/.*|(\\.|/)(test|spec))\\.tsx?$',
      moduleFileExtensions: ['ts', 'tsx', 'js', 'jsx', 'json', 'node'],
    }
    `;
    const tsConfig = `
    {
      "compilerOptions": {
        "target": "es5",
        "module": "commonjs",
        "lib": ["es2015"],
        "strict": true,
        "declaration": true,
        "outDir": "dist",
        "sourceMap": true
      },
      "include": ["src/**/*"],
      "exclude": ["node_modules", "**/*.spec.ts"]
    }
    `;
    const mainFile = `
    export const sum = (a: number, b: number) => a + b;
    `;
    const mainSpecFile = `
    import { sum } from './main';

    test('should return false given external link', () => {
      expect(sum(1, 2)).toBe(3);
    })

    test('should return true given internal link', () => {
      expect(sum(1, 2)).toBe(3);
    })
    `;
    fs.writeFileSync(`./${dir}/jest.config.js`, jestConfig);
    fs.writeFileSync(`./${dir}/sum.test.js`, tsConfig);

  } else {
    fs.writeFileSync(`./${dir}/sum.js`, funcExp);
    fs.writeFileSync(`./${dir}/tsconfig.json`, testExp);
    // fs.writeFileSync(`./${dir}/src/main.ts`, mainFile);
    // fs.writeFileSync(`./${dir}/src/main.spec.ts`, mainSpecFile);
  }
});
child.stdout.on('data', function (data) {
  console.log("STDOUT:", data.toString());
});
child.on('exit', function (exitCode) {
  console.log("Child exited with code: " + exitCode);
});
